From 7c6e67d9452117829b5b1baf29dd0cf530bbff37 Mon Sep 17 00:00:00 2001
From: Portisch <hugo.portisch@yahoo.de>
Date: Tue, 14 Jan 2025 09:23:49 +0100
Subject: [PATCH 5/9] [Subtitles][libass] Add EventActive function This
 function parse current events if there is an active one checked by pts.

---
 .../DVDSubtitles/DVDSubtitlesLibass.cpp       | 20 +++++++++++++++++++
 .../DVDSubtitles/DVDSubtitlesLibass.h         |  7 +++++++
 2 files changed, 27 insertions(+)

diff --git a/xbmc/cores/VideoPlayer/DVDSubtitles/DVDSubtitlesLibass.cpp b/xbmc/cores/VideoPlayer/DVDSubtitles/DVDSubtitlesLibass.cpp
index a35d2d7f3c..0bb02a84fa 100644
--- a/xbmc/cores/VideoPlayer/DVDSubtitles/DVDSubtitlesLibass.cpp
+++ b/xbmc/cores/VideoPlayer/DVDSubtitles/DVDSubtitlesLibass.cpp
@@ -563,6 +563,26 @@ int CDVDSubtitlesLibass::GetPlayResY()
   return m_track->PlayResY;
 }
 
+bool CDVDSubtitlesLibass::EventActive(double pts)
+{
+  std::unique_lock<CCriticalSection> lock(m_section);
+  if (!m_library || !m_track)
+  {
+    CLog::Log(LOGERROR, "{} - Missing ASS structs (m_library or m_track)", __FUNCTION__);
+    return false;
+  }
+
+  int64_t _pts(DVD_TIME_TO_MSEC(pts));
+  for (int i = 0; i < m_track->n_events; i++)
+  {
+    ASS_Event* assEvent = (m_track->events + i);
+    if (assEvent->Start <= _pts && (assEvent->Start + assEvent->Duration) > _pts)
+      return true;
+  }
+
+  return false;
+}
+
 void CDVDSubtitlesLibass::ConfigureAssOverride(const std::shared_ptr<struct style>& subStyle,
                                                ASS_Style* style)
 {
diff --git a/xbmc/cores/VideoPlayer/DVDSubtitles/DVDSubtitlesLibass.h b/xbmc/cores/VideoPlayer/DVDSubtitles/DVDSubtitlesLibass.h
index 67ae0449c3..9ccdb59588 100644
--- a/xbmc/cores/VideoPlayer/DVDSubtitles/DVDSubtitlesLibass.h
+++ b/xbmc/cores/VideoPlayer/DVDSubtitles/DVDSubtitlesLibass.h
@@ -83,6 +83,13 @@ public:
   */
   int GetPlayResY();
 
+  /*!
+  * \brief Check if currently an event is active
+  * \param pts as double
+  * \return True when there is any event active
+  */
+  bool EventActive(double pts);
+
 protected:
   /*!
   * \brief Create a new empty ASS track
-- 
2.43.0

